@@ -69,6 +69,12 @@ def parse_args():
   queue.add_argument('--on-failure', dest='on_failure', type=str, default=None,  help='function to be invoked on failure of the job')
   queue.add_argument('--max-attempts', dest='max_attempts', type=int, default=None,  help='maximum number of times to attempt executing job in case of failure')
 
+  initialize = subparsers.add_parser('init', description='Prepares database for job scheduling and worker')
+  initialize.add_argument('-u', '--conn', dest='db_conn', type=str, default="mongodb://localhost:27017",  help='mongodb connection string (default: mongodb://localhost:27017)')
+  initialize.add_argument('--dbname', dest='db_name', type=str, default="jobs",  help='mongodb database name (default: jobs)')
+  initialize.add_argument('--colname', dest='col_name', type=str, default="jobs",  help='mongodb collection name (default: jobs)')
+
+
   args = parser.parse_args()
 
   return args
@@ -81,6 +87,8 @@ def main():
     run_worker(args)
   elif str(action).lower() == "queue":
     run_queue(args)
+  elif str(action).lower() == "init":
+    run_init(args)
 
 def run_worker(args):
   from pymongo import MongoClient
@@ -144,4 +152,12 @@ def run_queue(args):
 
   jobId = queue.enqueue(args.function_name, **params)
   print(f"Job Successfully queued, {jobId}")
-  return jobId
\ No newline at end of file
+  return jobId
+
+def run_init(args):
+  from pymongo import MongoClient
+  client = MongoClient(args.db_conn)
+  db = client.get_database(args.db_name)
+  coll = db.get_collection(args.col_name)
+  coll.create_index("expireAt", expireAfterSeconds=0)
+  
\ No newline at end of file
